@@ -834,6 +834,7 @@ class EnhancedJSONEncoder(json.JSONEncoder):
 
 def build_all(
     dgraph_client_str: str,
+    edgedb_client_str: str,
     node_path_imports_str,
     schema: graphql.GraphQLSchema,
     node_configs: T.List[NodeConfig],
@@ -887,6 +888,7 @@ def build_all(
     lines = [
         imports(),
         dgraph_client_str,
+        edgedb_client_str,
         node_path_imports_str,
         enums,
         inputs,
@@ -981,6 +983,17 @@ async def login_client() -> None:
     return format_str(s, mode=FileMode())
 
 
+def build_edgedb_client(app_config: dict) -> str:
+    if "edgedb_host" not in app_config or "edgedb_password" not in app_config:
+        return ""
+    host, password = app_config.get("edgedb_host"), app_config.get("edgedb_password")
+    lines = [
+        "import edgedb",
+        f'edgedb_client = edgedb.create_async_client(tls_security="insecure", host="{host}", password="{password}")',
+    ]
+    return "\n".join(lines)
+
+
 def build_node_path_imports(node_configs: T.List[NodeConfig]) -> str:
     strs: T.List[str] = []
     for node in node_configs:
@@ -1008,10 +1021,12 @@ async def build_from_app_config(
         app_config.get("namespace"),
     )
     dgraph_client_str = build_dgraph_client(app_config)
+    edgedb_client_str = build_edgedb_client(app_config)
     node_path_imports_str = build_node_path_imports(node_configs)
     # build once for models, another for nodes if necessary
     s = build_all(
         dgraph_client_str=dgraph_client_str,
+        edgedb_client_str=edgedb_client_str,
         node_path_imports_str="",
         schema=schema,
         node_configs=node_configs,
@@ -1022,6 +1037,7 @@ async def build_from_app_config(
     if node_path_imports_str:
         s = build_all(
             dgraph_client_str=dgraph_client_str,
+            edgedb_client_str=edgedb_client_str,
             node_path_imports_str=node_path_imports_str,
             schema=schema,
             node_configs=node_configs,
